@@ -3,12 +3,10 @@ import re
 from contextlib import contextmanager
 
 from pydocx.parsers.Docx2Html import Docx2Html
-from pydocx.DocxParser import (
-    remove_namespaces,
-    # We are only importing this from DocxParse since we have added methods to
-    # it there.
-    ElementTree,
+from pydocx.utils import (
+    parse_xml_from_string,
 )
+from pydocx.tests.document_builder import DocxBuilder as DXB
 from unittest import TestCase
 
 STYLE = (
@@ -20,6 +18,10 @@ STYLE = (
     '.pydocx-left {text-align:left;}'
     '.pydocx-comment {color:blue;}'
     '.pydocx-underline {text-decoration: underline;}'
+    '.pydocx-caps {text-transform:uppercase;}'
+    '.pydocx-small-caps {font-variant: small-caps;}'
+    '.pydocx-strike {text-decoration: line-through;}'
+    '.pydocx-hidden {visibility: hidden;}'
     'body {width:612px;margin:0px auto;}'
     '</style>'
 )
@@ -84,22 +86,31 @@ class XMLDocx2Html(Docx2Html):
     Create the object without passing in a path to the document, set them
     manually.
     """
+    def __init__(self, *args, **kwargs):
+        # Pass in nothing for the path
+        super(XMLDocx2Html, self).__init__(path=None, *args, **kwargs)
+
     def _build_data(
             self,
+            path,
             document_xml=None,
             rels_dict=None,
             numbering_dict=None,
             styles_dict=None,
             *args, **kwargs):
         self._test_rels_dict = rels_dict
-        if numbering_dict is None:
-            numbering_dict = {}
+        if rels_dict:
+            for value in rels_dict.values():
+                self._image_data['word/%s' % value] = 'word/%s' % value
+        self.numbering_root = None
+        if numbering_dict is not None:
+            self.numbering_root = parse_xml_from_string(
+                DXB.numbering(numbering_dict),
+            )
         self.numbering_dict = numbering_dict
         # Intentionally not calling super
         if document_xml is not None:
-            self.root = ElementTree.fromstring(
-                remove_namespaces(document_xml),
-            )
+            self.root = parse_xml_from_string(document_xml)
         self.zip_path = ''
 
         # This is the standard page width for a word document, Also the page
@@ -145,6 +156,7 @@ class _TranslationTestCase(TestCase):
     run_expected_output = True
     parser = XMLDocx2Html
     use_base_html = True
+    convert_root_level_upper_roman = False
 
     def get_xml(self):
         raise NotImplementedError()
@@ -165,7 +177,13 @@ class _TranslationTestCase(TestCase):
         tree = self.get_xml()
 
         # Verify the final output.
-        html = self.parser(
+        parser = self.parser
+
+        def image_handler(self, src, *args, **kwargs):
+            return src
+        parser.image_handler = image_handler
+        html = parser(
+            convert_root_level_upper_roman=self.convert_root_level_upper_roman,
             document_xml=tree,
             rels_dict=self.relationship_dict,
             numbering_dict=self.numbering_dict,
